@@ -5,7 +5,7 @@ from gevent.select import select
 from gevent.monkey import patch_all; patch_all()
 import uuid
 
-from . import WebSocket, WebSocketClient, WebSocketMiddleware
+from .websocket import WebSocket, WebSocketClient, WebSocketMiddleware
 from ._uwsgi import uwsgi
 
 
@@ -27,6 +27,9 @@ class GeventWebSocketClient(object):
     def receive(self):
         return self.recv_queue.get()
 
+    def close(self):
+        self.connected = False
+
 
 class GeventWebSocketMiddleware(WebSocketMiddleware):
     client = GeventWebSocketClient
